[Zope-Checkins] CVS: ZODB3/ZEO/tests - zeoserver.py:1.19

Jeremy Hylton jeremy@zope.com
Thu, 5 Jun 2003 18:39:01 -0400


Update of /cvs-repository/ZODB3/ZEO/tests
In directory cvs.zope.org:/tmp/cvs-serv13425/ZEO/tests

Modified Files:
	zeoserver.py 
Log Message:
Fiddle comments and log message.


=== ZODB3/ZEO/tests/zeoserver.py 1.18 => 1.19 ===
--- ZODB3/ZEO/tests/zeoserver.py:1.18	Fri May 30 15:20:56 2003
+++ ZODB3/ZEO/tests/zeoserver.py	Thu Jun  5 18:39:01 2003
@@ -90,10 +90,10 @@
     def handle_accept(self):
         sock, addr = self.accept()
         self.log('in handle_accept()')
         # When we're done with everything, close the server.  Do not write
         # the ack character until the server is finished closing.
         if self._count <= 0:
-            self.log('closing the server')
+            self.log('closing the storage')
             self._server.close_server()
             if not self._keep:
                 for storage in self._server.storages.values():
@@ -90,10 +90,10 @@
         sock, addr = self.accept()
         self.log('in handle_accept()')
-        # When we're done with everything, close the server.  Do not write
-        # the ack character until the server is finished closing.
+        # When we're done with everything, close the storage.  Do not write
+        # the ack character until the storage is finished closing.
         if self._count <= 0: